@@ -28,19 +28,19 @@ sub GSL_HISTOGRAM2D_ALLOC : Tests {
 sub GSL_HISTOGRAM2D_SET_RANGES : Tests { 
     my $self = shift;
     my $ranges = [ 0 .. 100];
-    ok_status(gsl_histogram2d_set_ranges($self->{H}, $ranges, 100 + 1, $ranges, 100+1));
+    ok_status(gsl_histogram2d_set_ranges($self->{H}, $ranges, 100 + 1, $ranges, 100+1), $GSL_SUCCESS);
 }
 
 sub GSL_HISTOGRAM2D_SET_RANGES_UNIFORM : Tests {
     my $self = shift;
-    ok_status(gsl_histogram2d_set_ranges_uniform($self->{H}, 0, 100, 0, 100));
+    ok_status(gsl_histogram2d_set_ranges_uniform($self->{H}, 0, 100, 0, 100), $GSL_SUCCESS);
 }
 
 sub MEMCPY : Tests {
     my $self = shift;
     my $copy = gsl_histogram2d_alloc(100,100);
 
-    ok_status(gsl_histogram2d_memcpy($copy, $self->{H}));
+    ok_status(gsl_histogram2d_memcpy($copy, $self->{H}), $GSL_SUCCESS);
 
     my $bob = gsl_histogram2d_alloc(50,50);
     ok_status(gsl_histogram2d_memcpy($bob, $self->{H}), $GSL_EINVAL);
@@ -57,7 +57,7 @@ sub INCREMENT : Tests {
     my $self = shift;
     gsl_histogram2d_set_ranges_uniform($self->{H}, 0, 100, 0, 100);
 
-    ok_status(gsl_histogram2d_increment($self->{H}, 50.5, 50.5 ));
+    ok_status(gsl_histogram2d_increment($self->{H}, 50.5, 50.5 ), $GSL_SUCCESS);
     ok_status(gsl_histogram2d_increment($self->{H}, -150.5, -150.5 ), $GSL_EDOM);
     ok_status(gsl_histogram2d_increment($self->{H}, 150.5, 150.5 ), $GSL_EDOM);
 }
@@ -66,7 +66,7 @@ sub GET : Tests {
     my $self = shift;
     gsl_histogram2d_set_ranges_uniform($self->{H}, 0, 100, 0, 100);
 
-    ok_status(gsl_histogram2d_increment($self->{H}, 50.5, 50.5 ));
+    ok_status(gsl_histogram2d_increment($self->{H}, 50.5, 50.5 ), $GSL_SUCCESS);
     cmp_ok(1,'==', gsl_histogram2d_get($self->{H}, 50, 50 ) );
 }
 
@@ -82,7 +82,7 @@ sub XMIN_XMAX_YMIN_YMAX : Tests {
 sub MIN_VAL_MAX_VAL : Tests {
     my $self = shift;
     gsl_histogram2d_set_ranges_uniform($self->{H}, 0, 100, 0, 100);
-    ok_status(gsl_histogram2d_increment($self->{H}, 50.5, 50.5 ));
+    ok_status(gsl_histogram2d_increment($self->{H}, 50.5, 50.5 ), $GSL_SUCCESS);
 
     cmp_ok(1,'==', gsl_histogram2d_max_val($self->{H}));
     cmp_ok(0,'==', gsl_histogram2d_min_val($self->{H}));
@@ -91,8 +91,8 @@ sub MIN_VAL_MAX_VAL : Tests {
 sub MEAN : Tests {
     my $self = shift;
     gsl_histogram2d_set_ranges_uniform($self->{H}, 0, 100, 0, 100);
-    ok_status(gsl_histogram2d_increment($self->{H}, 50.5, 50.5 ));
-    ok_status(gsl_histogram2d_increment($self->{H}, 11.5, 11.5 ));
+    ok_status(gsl_histogram2d_increment($self->{H}, 50.5, 50.5 ), $GSL_SUCCESS);
+    ok_status(gsl_histogram2d_increment($self->{H}, 11.5, 11.5 ), $GSL_SUCCESS);
 
     ok_similar(31, gsl_histogram2d_xmean($self->{H}));
     ok_similar(31, gsl_histogram2d_ymean($self->{H}));
@@ -102,15 +102,15 @@ sub SUM : Tests {
     my $self = shift;
     gsl_histogram2d_set_ranges_uniform($self->{H}, 0, 100, 0, 100);
     
-    ok_status(gsl_histogram2d_increment($self->{H}, 50.5, 50.5 ));
-    ok_status(gsl_histogram2d_increment($self->{H}, 11.5, 11.5 ));
+    ok_status(gsl_histogram2d_increment($self->{H}, 50.5, 50.5 ), $GSL_SUCCESS);
+    ok_status(gsl_histogram2d_increment($self->{H}, 11.5, 11.5 ), $GSL_SUCCESS);
     ok_similar(2, gsl_histogram2d_sum($self->{H}));
 }
 
 sub SHIFT : Tests {
     my $h = gsl_histogram2d_alloc(5,5);
     gsl_histogram2d_set_ranges_uniform($h, 0, 5, 0, 5);
-    ok_status(gsl_histogram2d_shift($h, 2));
+    ok_status(gsl_histogram2d_shift($h, 2), $GSL_SUCCESS);
     for my $i (0..4) {
     is_deeply( [ map { gsl_histogram2d_get($h, $_, $i) } (0..4) ],
                [ (2) x 5 ]
@@ -119,16 +119,16 @@ sub SHIFT : Tests {
 
 sub FWRITE_FREAD : Tests {
     my $H = gsl_histogram2d_alloc(5,5);
-    my $stream = gsl_fopen("histogram2d", 'w');
+    my $stream = fopen("histogram2d", "w");
     gsl_histogram2d_set_ranges_uniform($H, 0, 5, 0, 5);
-    ok_status(gsl_histogram2d_increment($H, 0.5, 1.5 ));
+    ok_status(gsl_histogram2d_increment($H, 0.5, 1.5 ), $GSL_SUCCESS);
 
-    ok_status(gsl_histogram2d_fwrite($stream, $H));  
-    ok_status(gsl_fclose($stream));
+    ok_status(gsl_histogram2d_fwrite($stream, $H),$GSL_SUCCESS);  
+    fclose($stream);
    
-    $stream = gsl_fopen("histogram2d", 'r');
+    $stream = fopen("histogram2d", "r");
     my $h = gsl_histogram2d_alloc(5, 5);  
-    ok_status(gsl_histogram2d_fread($stream, $h));  
+    ok_status(gsl_histogram2d_fread($stream, $h),$GSL_SUCCESS);  
     is_deeply( [ map { gsl_histogram2d_get($h, 0, $_) } (0..4) ],
                [ 0, 1, (0) x 3 ]
     );
@@ -136,16 +136,16 @@ sub FWRITE_FREAD : Tests {
     is_deeply( [ map { gsl_histogram2d_get($h, $i, $_) } (0..4) ],
                [ (0) x 5 ]
     );}
-    ok_status(gsl_fclose($stream));
+    fclose($stream);
 }
 
 sub GET_XRANGE_YRANGE : Tests {
     my $self = shift;
     gsl_histogram2d_set_ranges_uniform($self->{H}, 0, 100, 0, 100);
     my @got = gsl_histogram2d_get_xrange($self->{H}, 50);
-    ok_status($got[0]);
+    ok_status($got[0], $GSL_SUCCESS);
     @got = gsl_histogram2d_get_yrange($self->{H}, 50);
-    ok_status($got[0]);
+    ok_status($got[0], $GSL_SUCCESS);
     is_deeply( [ $got[1], $got[2]], [50, 51]);
     is_deeply( [ $got[1], $got[2]], [50, 51]);
 }
@@ -154,7 +154,7 @@ sub FIND : Tests {
     my $self = shift;
     gsl_histogram2d_set_ranges_uniform($self->{H}, 0, 100, 0, 100);
     my @got = gsl_histogram2d_find($self->{H}, 1, 1);
-    ok_status($got[0]);
+    ok_status($got[0], $GSL_SUCCESS);
     cmp_ok($got[1], '==', 1);
     cmp_ok($got[2], '==', 1);
 }
@@ -163,7 +163,7 @@ sub ACCUMULATE : Tests {
     my $self = shift;
     gsl_histogram2d_set_ranges_uniform($self->{H}, 0, 100, 0, 100);
 
-    ok_status(gsl_histogram2d_accumulate($self->{H}, 50.5, 50.5, 3 ));
+    ok_status(gsl_histogram2d_accumulate($self->{H}, 50.5, 50.5, 3 ), $GSL_SUCCESS);
     cmp_ok(3,'==', gsl_histogram2d_get($self->{H}, 50, 50 ) );
     ok_status(gsl_histogram2d_accumulate($self->{H}, -150.5, -150.5, 3 ), $GSL_EDOM);
 }
@@ -214,7 +214,7 @@ sub ADD : Tests {
     gsl_histogram2d_set_ranges_uniform($self->{H}, 0, 100, 0, 100);
     gsl_histogram2d_set_ranges_uniform($h2, 0, 100, 0, 100);
     gsl_histogram2d_increment($h2, 50.5, 50.5 );
-    ok_status(gsl_histogram2d_add($self->{H}, $h2));
+    ok_status(gsl_histogram2d_add($self->{H}, $h2), $GSL_SUCCESS);
     cmp_ok(gsl_histogram2d_get($self->{H}, 50, 50), '==', 1);
 }
 
@@ -225,7 +225,7 @@ sub SUB : Tests {
     gsl_histogram2d_set_ranges_uniform($h2, 0, 100, 0, 100);
     gsl_histogram2d_increment($h2, 50.5, 50.5 );
     gsl_histogram2d_increment($self->{H}, 50.5, 50.5 );
-    ok_status(gsl_histogram2d_sub($self->{H}, $h2));
+    ok_status(gsl_histogram2d_sub($self->{H}, $h2), $GSL_SUCCESS);
     cmp_ok(gsl_histogram2d_get($self->{H}, 50, 50), '==', 0);
 }
 
@@ -236,7 +236,7 @@ sub MUL : Tests {
     gsl_histogram2d_set_ranges_uniform($h2, 0, 100, 0, 100);
     gsl_histogram2d_accumulate($h2, 50.5, 50.5, 2);
     gsl_histogram2d_accumulate($self->{H}, 50.5, 50.5, 3);
-    ok_status(gsl_histogram2d_mul($self->{H}, $h2));
+    ok_status(gsl_histogram2d_mul($self->{H}, $h2), $GSL_SUCCESS);
     cmp_ok(gsl_histogram2d_get($self->{H}, 50, 50), '==', 6);
 }
 
@@ -247,7 +247,7 @@ sub DIV	: Tests {
     gsl_histogram2d_set_ranges_uniform($h2, 0, 100, 0, 100);
     gsl_histogram2d_accumulate($h2, 50.5, 50.5, 2);
     gsl_histogram2d_accumulate($self->{H}, 50.5, 50.5, 4);
-    ok_status(gsl_histogram2d_div($self->{H}, $h2));
+    ok_status(gsl_histogram2d_div($self->{H}, $h2), $GSL_SUCCESS);
     cmp_ok(gsl_histogram2d_get($self->{H}, 50, 50), '==', 2);
 }
 
@@ -256,23 +256,23 @@ sub SCALE : Tests {
     gsl_histogram2d_set_ranges_uniform($self->{H}, 0, 100, 0, 100);
     gsl_histogram2d_accumulate($self->{H}, 50.5, 50.5, 4);
     gsl_histogram2d_increment($self->{H}, 33.5, 33.5 );
-    ok_status(gsl_histogram2d_scale($self->{H}, 2));
+    ok_status(gsl_histogram2d_scale($self->{H}, 2), $GSL_SUCCESS);
     cmp_ok(gsl_histogram2d_get($self->{H}, 50, 50), '==', 8);
     cmp_ok(gsl_histogram2d_get($self->{H}, 33, 33), '==', 2);
 }
 
 sub FPRINTF_FSCANF : Tests {
     my $H = gsl_histogram2d_alloc(5,5);
-    my $stream = gsl_fopen("histogram2d", 'w');
+    my $stream = fopen("histogram2d", "w");
     gsl_histogram2d_set_ranges_uniform($H, 0, 5, 0, 5);
-    ok_status(gsl_histogram2d_increment($H, 0.5, 0.5 ));
+    ok_status(gsl_histogram2d_increment($H, 0.5, 0.5 ), $GSL_SUCCESS);
 
-    ok_status(gsl_histogram2d_fprintf($stream, $H, "%e", "%e"));  
-    ok_status(gsl_fclose($stream));
+    ok_status(gsl_histogram2d_fprintf($stream, $H, "%e", "%e"),$GSL_SUCCESS);  
+    fclose($stream);
    
-    $stream = gsl_fopen("histogram2d", 'r');
+    $stream = fopen("histogram2d", "r");
     my $h = gsl_histogram2d_alloc(5,5);  
-    ok_status(gsl_histogram2d_fscanf($stream, $h));  
+    ok_status(gsl_histogram2d_fscanf($stream, $h),$GSL_SUCCESS);  
     is_deeply( [ map { gsl_histogram2d_get($h, 0, $_) } (0..4) ],
                [ 1, (0) x 4 ]
     );
@@ -280,7 +280,7 @@ sub FPRINTF_FSCANF : Tests {
     is_deeply( [ map { gsl_histogram2d_get($h, $i, $_) } (0..4) ],
                [ (0) x 5 ]
     );}
-    ok_status(gsl_fclose($stream));
+    fclose($stream);
 }
 
 sub PDF_ALLOC : Tests {
@@ -294,7 +294,7 @@ sub PDF_INIT : Tests {
     my $self = shift;
     my $p = gsl_histogram2d_pdf_alloc(100, 100);
     gsl_histogram2d_set_ranges_uniform($self->{H}, 0, 100, 0, 100);
-    ok_status(gsl_histogram2d_pdf_init ($p, $self->{H}));
+    ok_status(gsl_histogram2d_pdf_init ($p, $self->{H}),$GSL_SUCCESS);
     gsl_histogram2d_accumulate($self->{H}, 50.5, 50.5, -4);
     ok_status(gsl_histogram2d_pdf_init ($p, $self->{H}), $GSL_EDOM);
 }
