@@ -24,34 +24,32 @@ sub teardown : Test(teardown) {
 }
 
 sub GSL_LINALG_LU_DECOMP : Tests {
-    my $base = Math::GSL::Matrix->new(4,4);
-    $base->set_row(0, [0,1,2,3])
-         ->set_row(1, [5,6,7,8])
-         ->set_row(2, [9,10,11,12])
-         ->set_row(3, [13,14,15,16]);
+    my $self = shift;
+    map { gsl_matrix_set($self->{matrix}, 0, $_, $_+1) } (0..3); 
+    map { gsl_matrix_set($self->{matrix}, 1, $_, $_+5) } (0..3); 
+    map { gsl_matrix_set($self->{matrix}, 2, $_, $_+9) } (0..3); 
+    map { gsl_matrix_set($self->{matrix}, 3, $_, $_+13) } (0..3); 
     my $permutation = gsl_permutation_alloc(4);
     gsl_permutation_init($permutation);
-    my $first = Math::GSL::Matrix->new(4,4);
-    gsl_matrix_memcpy($first->raw, $base->raw);
+    my $first = gsl_matrix_alloc(4,4);
+    gsl_matrix_memcpy($first, $self->{matrix});
 
-    my ($result, $signum) = gsl_linalg_LU_decomp($base->raw, $permutation);
+    my ($result, $signum) = gsl_linalg_LU_decomp($self->{matrix}, $permutation);
     is_deeply( [ $result, $signum ], [ 0, 1] );
  
-    my $U = Math::GSL::Matrix->new(4,4);
-    my $R = Math::GSL::Matrix->new(4,4);
-    my $L = Math::GSL::Matrix->new(4,4);
-    gsl_matrix_set_identity($L->raw);
+    local $TODO = "no test for this function in gsl source";
+    my $U = gsl_matrix_calloc(4,4);
+    my $R = gsl_matrix_calloc(4,4);
     my $line;
     for ($line=3; $line>-1; $line--) {
-     map { gsl_matrix_set($U->raw, $line, $_, gsl_matrix_get($base->raw, $line, $_)) } ($line..3) };
+     map { gsl_matrix_set($U, $_, $line, gsl_matrix_get($self->{matrix}, $_, $line)) } ($line..3) };
+    my $L = gsl_matrix_calloc(4,4);
+    gsl_matrix_set_identity($L);
     for ($line=3; $line>1; $line--) {
-     map { gsl_matrix_set($L->raw, $line, $_, gsl_matrix_get($base->raw, $line, $_)) } (0..$line-1) };
-    gsl_blas_dgemm($CblasNoTrans, $CblasNoTrans, 1, $L->raw, $U->raw, 1, $R->raw);
-    my @permutations = map { gsl_permutation_get($permutation, $_) } (0..3);
-    map {
-    my @got = $first->row($permutations[$_])->as_list;
-    my @results = $R->row($_)->as_list;
-    ok_similar([@got], [@results], "resulting row $_"); } (0..3);
+     map { gsl_matrix_set($L, $_, $line, gsl_matrix_get($self->{matrix}, $_, $line)) } (0..$line-2) };
+    gsl_blas_dgemm($CblasNoTrans, $CblasNoTrans, 1, $L, $U, 1, $R);
+    for ($line=0; $line<4; $line++) {
+     map { ok(is_similar_relative(gsl_matrix_get($R, $line, $_), gsl_matrix_get($first, $line, $_), 2 * 64 * $GSL_DBL_EPSILON)) } (0..3); }
 }
 
 sub GSL_LINALG_LU_SOLVE : Tests {
@@ -246,7 +244,7 @@ sub GSL_LINALG_QR_DECOMP : Tests {
     my $save = gsl_matrix_alloc(3, 5);
     gsl_matrix_memcpy($save, $matrix);
 
-    ok_status(gsl_linalg_QR_decomp($matrix, $tau));
+    ok_status(gsl_linalg_QR_decomp($matrix, $tau),$GSL_SUCCESS);
     is(gsl_linalg_QR_unpack($matrix, $tau, $q, $r), 0);
   # compute a = q r 
   gsl_blas_dgemm ($CblasNoTrans, $CblasNoTrans, 1.0, $q, $r, 0.0, $a);
@@ -281,7 +279,7 @@ sub GSL_LINALG_CHOLESKY_DECOMP : Tests {
     gsl_matrix_set($self->{matrix}, 3, 2, 20);
     gsl_matrix_set($self->{matrix}, 3, 3, 30);
    
-    ok_status(gsl_linalg_cholesky_decomp($self->{matrix}));
+    ok_status(gsl_linalg_cholesky_decomp($self->{matrix}), $GSL_SUCCESS);
     my $v = gsl_matrix_diagonal($self->{matrix});
     ok_similar( 
         [ map { gsl_vector_get($v->{vector}, $_)} (0..3) ], [(1)x 4 ]
@@ -316,9 +314,9 @@ sub GSL_LINALG_HESSENBERG_DECOMP_UNPACK_UNPACK_ACCUM_SET_ZERO : Tests {
     gsl_matrix_set($self->{matrix}, 3, 2, 2);
     gsl_matrix_set($self->{matrix}, 3, 3, -8);   
     my $tau = gsl_vector_alloc(4);
-    ok_status(gsl_linalg_hessenberg_decomp($self->{matrix}, $tau));
+    ok_status(gsl_linalg_hessenberg_decomp($self->{matrix}, $tau),$GSL_SUCCESS);
     my $U = gsl_matrix_alloc(4,4);
-    ok_status(gsl_linalg_hessenberg_unpack($self->{matrix}, $tau, $U));
+    ok_status(gsl_linalg_hessenberg_unpack($self->{matrix}, $tau, $U),$GSL_SUCCESS);
     is(gsl_matrix_get($U, 0, 0), 1);
     map { is(gsl_matrix_get($U, $_, 0), 0) } (1..3);
     map { is(gsl_matrix_get($U, 0, $_), 0) } (1..3);
@@ -365,12 +363,12 @@ sub GSL_LINALG_BIDIAG_DECOMP_UNPACK_UNPACK2_UNPACK_B : Tests {
     my $tau_U = gsl_vector_alloc(4);
     my $tau_V = gsl_vector_alloc(3);
 
-    ok_status(gsl_linalg_bidiag_decomp($self->{matrix}, $tau_U, $tau_V));
+    ok_status(gsl_linalg_bidiag_decomp($self->{matrix}, $tau_U, $tau_V),$GSL_SUCCESS);
     my $U = gsl_matrix_alloc(4,4);
     my $V = gsl_matrix_alloc(4,4);
     my $diag = gsl_vector_alloc(4);
     my $superdiag = gsl_vector_alloc(3);
-    ok_status(gsl_linalg_bidiag_unpack($self->{matrix}, $tau_U, $U, $tau_V, $V, $diag, $superdiag));
+    ok_status(gsl_linalg_bidiag_unpack($self->{matrix}, $tau_U, $U, $tau_V, $V, $diag, $superdiag),$GSL_SUCCESS);
     is(gsl_matrix_get($V, 0, 0), 1);    
     ok_similar( [ map { gsl_matrix_get($V, $_, 0) } (1..3) ], [ (0) x 3 ] ); 
     ok_similar( [ map { gsl_matrix_get($V, 0, $_) } (1..3) ], [ (0) x 3 ] ); 
