@@ -111,7 +111,7 @@ sub GSL_MATRIX_SWAP : Tests {
    map { gsl_matrix_set($self->{matrix}, $_,$_, $_ ** 2) } (0..4);
    my $matrix = gsl_matrix_alloc(5,5);
    map { gsl_matrix_set($matrix, $_,$_, $_) } (0..4);
-   ok_status(gsl_matrix_swap($self->{matrix}, $matrix));
+   ok_status(gsl_matrix_swap($self->{matrix}, $matrix), $GSL_SUCCESS);
 
    my @got = map { gsl_matrix_get($self->{matrix}, $_, $_) } (0..4);
    map { is($got[$_], $_) } (0..4);
@@ -123,7 +123,7 @@ sub GSL_MATRIX_MEMCPY : Tests {
    my $self = shift;
    my $matrix = gsl_matrix_alloc(5,5);
    map { gsl_matrix_set($self->{matrix}, $_,$_, $_ ** 2) } (0..4);
-   ok_status(gsl_matrix_memcpy($matrix, $self->{matrix}));
+   ok_status(gsl_matrix_memcpy($matrix, $self->{matrix}), $GSL_SUCCESS);
    ok_similar( [ map { gsl_matrix_get($matrix, $_, $_) } (0..4) ], 
                [ map {  $_** 2 } (0..4)                        ]
    );  
@@ -133,7 +133,7 @@ sub GSL_MATRIX_SWAP_ROWS : Tests {
    my $self = shift; 
    map { gsl_matrix_set($self->{matrix}, 0,$_, $_) } (0..4);
    map { gsl_matrix_set($self->{matrix}, 1,$_, 3) } (0..4);
-   ok_status(gsl_matrix_swap_rows($self->{matrix}, 0, 1));
+   ok_status(gsl_matrix_swap_rows($self->{matrix}, 0, 1), $GSL_SUCCESS);
    my @got = map { gsl_matrix_get($self->{matrix}, 1, $_) } (0..4);
    map { is($got[$_], $_) } (0..4);   
    @got = map { gsl_matrix_get($self->{matrix}, 0, $_) } (0..4);
@@ -144,7 +144,7 @@ sub GSL_MATRIX_SWAP_COLUMNS : Tests {
    my $self = shift;
    map { gsl_matrix_set($self->{matrix}, $_,0, $_) } (0..4);
    map { gsl_matrix_set($self->{matrix}, $_,1, 3) } (0..4);
-   ok_status(gsl_matrix_swap_columns($self->{matrix}, 0, 1));
+   ok_status(gsl_matrix_swap_columns($self->{matrix}, 0, 1), $GSL_SUCCESS);
    my @got = map { gsl_matrix_get($self->{matrix}, $_, 1) } (0..4);
    map { is($got[$_], $_) } (0..4);   
    @got = map { gsl_matrix_get($self->{matrix}, $_, 0) } (0..4);
@@ -155,7 +155,7 @@ sub GSL_MATRIX_SWAP_ROWCOL : Tests {
    my $self = shift;
    map { gsl_matrix_set($self->{matrix}, 0,$_, $_) } (0..4);
    map { gsl_matrix_set($self->{matrix}, $_,2, 2) } (0..4);
-   ok_status(gsl_matrix_swap_rowcol($self->{matrix}, 0, 2));
+   ok_status(gsl_matrix_swap_rowcol($self->{matrix}, 0, 2), $GSL_SUCCESS);
    
    my @got = map { gsl_matrix_get($self->{matrix}, $_, 2) } (0..4);
    is_deeply( [ @got ], [ qw/2 1 0 3 4/  ] );
@@ -168,7 +168,7 @@ sub GSL_MATRIX_TRANSPOSE_MEMCPY : Tests {
    my $self = shift;
    map { gsl_matrix_set($self->{matrix}, 0,$_, $_) } (0..4);
    my $matrix = gsl_matrix_alloc(5,5); 
-   ok_status(gsl_matrix_transpose_memcpy($matrix, $self->{matrix}));   
+   ok_status(gsl_matrix_transpose_memcpy($matrix, $self->{matrix}), $GSL_SUCCESS);   
    my @got = map { gsl_matrix_get($matrix, $_, 0) } (0..4);
    map { is($got[$_], $_) } (0..4);
 }
@@ -389,15 +389,15 @@ sub GSL_MATRIX_FREAD_FWRITE : Tests {
         map { gsl_matrix_set($self->{matrix}, $line, $_, $_**2) } (0..4); 
    }
 
-   my $fh = gsl_fopen("matrix", 'w');
+   my $fh = fopen("matrix", "w");
    is( gsl_matrix_fwrite($fh, $self->{matrix}), 0);
-   gsl_fclose($fh);
+   fclose($fh);
 
    for my $line (0..4) {
         map { gsl_matrix_set($self->{matrix}, $line, $_, $_**3) } (0..4); 
    }
 
-   $fh = gsl_fopen("matrix", 'r');   
+   $fh = fopen("matrix", "r");   
    
    is(gsl_matrix_fread($fh, $self->{matrix}), 0);
    for my $line (0..4) {
@@ -406,7 +406,7 @@ sub GSL_MATRIX_FREAD_FWRITE : Tests {
                     [ map { $_**2 } (0..4) ],
                   );
    }
-   gsl_fclose($fh); 
+   fclose($fh); 
 }
 
 sub GSL_MATRIX_FPRINTF_FSCANF : Tests {
@@ -416,9 +416,7 @@ sub GSL_MATRIX_FPRINTF_FSCANF : Tests {
         map { gsl_matrix_set($self->{matrix}, $line, $_, $_**2) } (0..4); 
    }
 
-   my $write = is_windows() ? "w + b" : "w";
-   my $read  = is_windows() ? "r + b" : "r";
-   my $fh = fopen("matrix", $write);
+   my $fh = fopen("matrix", "w");
    is( gsl_matrix_fprintf($fh, $self->{matrix}, "%f"), 0);
    fclose($fh);
 
@@ -426,7 +424,7 @@ sub GSL_MATRIX_FPRINTF_FSCANF : Tests {
         map { gsl_matrix_set($self->{matrix}, $line, $_, $_**3) } (0..4); 
    }
 
-   $fh = fopen("matrix", $read);   
+   $fh = fopen("matrix", "r");   
    
    is(gsl_matrix_fscanf($fh, $self->{matrix}), 0);
    for my $line (0..4) {
@@ -493,9 +491,6 @@ sub ROW : Tests {
     my $matrix = Math::GSL::Matrix->new(5,5);
     map { gsl_matrix_set($matrix->raw, $_, $_, 5 + $_**2) } (0..4);
     ok_similar( [qw/0 0 9 0 0/] , [$matrix->row(2)->as_list ] );
-    map { gsl_matrix_set($matrix->raw, 0, $_, $_) } (0..4);
-    ok_similar( [qw/0 1 2 3 4/] , [$matrix->row(0)->as_list ] );
-    
 }
 
 sub COL : Tests {
